---
title: Gramex Guide
classes: toc
prefix: Guide
...

<link rel="stylesheet" href="search/search.css?v=1">

<input type="search" id="search" placeholder="Search topics" data-url="search/searchindex.json">
[Index of topics](search/)
<script src="node_modules/lunr/lunr.js"></script>
<script src="search/search.js?v=a"></script>


## Table of contents

- [Install Gramex](install/)
- [Tutorials](tutorials/)
    - [Quickstart](tutorials/quickstart/)
    - [Dashboards](tutorials/dashboards/)
    - [Charts](tutorials/charts/)
    - [Dropdown & Search](tutorials/g1-dropdown)
- [Gramex is a web server](server/)
- [Configurations control Gramex](config/)
- [Testing Gramex apps](test/)
- [Snippets (Visual Studio Code Extension)](snippets/)
- [FAQ](faq/)

## Reference

- [FunctionHandler runs Python code](functionhandler/)
- [FileHandler renders files](filehandler/)
- [FormHandler connects to data](formhandler/)
- [FilterHandler filters columns](filterhandler/)
- [JSONHandler writes JSON data](jsonhandler/)
- [CaptureHandler takes screenshots](capturehandler/)
- [PPTXHandler generates PPTX](pptxhandler/)
- [Auth handlers log in users](auth/)
- [ProxyHandler proxies APIs](proxyhandler/)
- [UploadHandler uploads files](uploadhandler/)
- [ProcessHandler runs programs](processhandler/)
- [WebSocketHandler](websockethandler/)
- [TwitterRESTHandler](twitterresthandler/)
- [FacebookGraphHandler](facebookgraphhandler/)
- [UI components](uicomponents/)
- [Charts](chart/)
- [Cache requests](cache/)
- [Send emails](email/)
- [Smart alerts](alert/)
- [Schedule tasks](scheduler/)
- [Watch files](watch/)
- [Admin page](admin/)
- [View logs](logviewer/)
- [Run apps](apps/)
- [Writing handlers](handlers/)
- [Debug Gramex](debug/)
- [Mapviewer](mapviewer/)
- [LanguageTool](languagetool/)
- [Release Notes](release/)
- [Python API reference](https://learn.gramener.com/gramex/gramex.html)
- [Gramex License](license/)

## Guides

- [Tips & Tricks](tips/)
- [Deployment patterns](deploy/)
- [Try out some exercises](exercises/)
- [Contributing to Gramex](contributing/)

## Demos

- [Speech recognition demo](speech/)

### Deprecated

- [DataHandler](datahandler/) - use [FormHandler](formhandler/) instead
- [QueryHandler](queryhandler/) - use [FormHandler](formhandler/) instead

## Additional links

- [Link check](linkcheck/) tests if all links on the Gramex Guide are working
- [Gramex roadmap](https://docs.google.com/spreadsheets/d/1D2xScjMWl29JtuuVP7PlsLM3OPJuMBr0VNvzzoR4HwQ/edit#gid=885343597)
